TabData class

Represents data for a tab in a tab bar.

Constructors

TabData({required IconData iconData, required String title, Function? onClick, Color? tabColor, BorderRadius? borderRadius, Gradient? tabGradient, Key? key})
Constructs a TabData instance with the following parameters:
const

Properties

borderRadius → BorderRadius?
Border radius of the tab.
final
hashCode → int
The hash code for this object.
no setterinherited
iconData → IconData
Icon data to be displayed in the tab.
final
key → Key?
Unique key for the tab.
final
onClick → Function?
Function to be called when the tab is clicked.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tabColor → Color?
Background color of the tab.
final
tabGradient → Gradient?
Background gradient of the tab.
final
title → String
Text to be displayed inside the tab.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited